api.alarms.v1.test_helpers.signature package — Argus-Toolbelt 1.0 documentation

# api.alarms.v1.test_helpers.signature package

## Submodules

## api.alarms.v1.test_helpers.signature.get_signatures module

`api.alarms.v1.test_helpers.signature.get_signatures.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/signature, respond with HTTP 403

`api.alarms.v1.test_helpers.signature.get_signatures.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/signature, respond with HTTP 404

`api.alarms.v1.test_helpers.signature.get_signatures.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/signature, respond with HTTP 200

`api.alarms.v1.test_helpers.signature.get_signatures.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/signature, respond with HTTP 401

## api.alarms.v1.test_helpers.signature.search_signatures module

`api.alarms.v1.test_helpers.signature.search_signatures.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/signature/search, respond with HTTP 403

`api.alarms.v1.test_helpers.signature.search_signatures.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/signature/search, respond with HTTP 404

`api.alarms.v1.test_helpers.signature.search_signatures.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/signature/search, respond with HTTP 200

`api.alarms.v1.test_helpers.signature.search_signatures.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/alarms/v1/signature/search, respond with HTTP 401

## Module contents